(internal)=

# Module reference

These internal modules are used by `Solution` but typically are not directly accessed by the user.

## Salt Matching module

```{eval-rst}
.. automodule:: pyEQL.salt_ion_match
    :members:
    :private-members:
```

## Modeling Engines module

```{eval-rst}
.. automodule:: pyEQL.engines
    :members:
```

## Activity Correction functions

```{eval-rst}
.. automodule:: pyEQL.activity_correction
    :members:
    :private-members:
```

## Speciation functions

```{eval-rst}
.. automodule:: pyEQL.equilibrium
    :members:
    :private-members:
```

## Utilities

```{eval-rst}
.. automodule:: pyEQL.utils
    :members:
    :private-members:
```
